import os
from bluer_options.env import load_config, load_env, get_env

load_env(__name__)
load_config(__name__)


BLUER_BEAST_MODEL = get_env("BLUER_BEAST_MODEL")

BLUER_UGV_CAMERA_TRAINING_PERIOD = get_env("BLUER_UGV_CAMERA_TRAINING_PERIOD", 3.0)
BLUER_UGV_CAMERA_PREDICTION_PERIOD = get_env("BLUER_UGV_CAMERA_PREDICTION_PERIOD", 1.5)

BLUER_UGV_SWALLOW_STEERING_SETPOINT = get_env("BLUER_UGV_SWALLOW_STEERING_SETPOINT", 50)

BLUER_UGV_MOUSEPAD_ENABLED = get_env("BLUER_UGV_MOUSEPAD_ENABLED", 0)

BLUER_UGV_SWALLOW_DATASET_LIST = get_env("BLUER_UGV_SWALLOW_DATASET_LIST", "")

BLUER_UGV_SWALLOW_MODEL = get_env("BLUER_UGV_SWALLOW_MODEL", "")
